; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCF_bc"
command = ~D, DF, F, b+c

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "BF_x"
command = ~$B, F, x

[Command]
name = "BF_y"
command = ~$B, F, y

[Command]
name = "BF_c"
command = ~$B, F, c

[Command]
name = "BF_xy"
command = ~$B, F, x+y

[Command]
name = "BF_xz"
command = ~$B, F, x+z

[Command]
name = "BF_bc"
command = ~$B, F, b+c

[Command]
name = "xyz"
command = x+y+z
time = 1

[Command]
name = "abc"
command = a+b+c
time = 1

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| AI |--------------------------------------------------------------
[Command]
name = "AI1"
command = U,D,B,F,U,D,B,F,b,b,a,a,s
time = 0

[Command]
name = "AI2"
command = U,D,U,D,U,D,U,D,U,D,U,D,a+b+c+x+y+z
time = 0

[Command]
name = "AI3"
command = U,F,B,D,B,F,U,x,x,x,y,y,y,z,z,z
time = 0

[Command]
name = "AI4"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0

[Command]
name = "AI5"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0

[Command]
name = "AI6"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0

[Command]
name = "AI7"
command = x+y+z,x+y+z,x+y+z,x+y+z,x+y+z,x+y+z,x+y+z
time = 0

[Command]
name = "AI8"
command = a+b+c,a+b+c,a+b+c,a+b+c,a+b+c,a+b+c,a+b+c
time = 0

[Command]
name = "AI9"
command = y,a,B,B,a,D,a,B,B,a
time = 0

[Command]
name = "AI10"
command = c,U,B,B,y,B,U,D,D,y
time = 0

[Command]
name = "AI11"
command = x,x,x,x
time = 0

[Command]
name = "AI12"
command = y,y,y,y
time = 0

[Command]
name = "AI13"
command = z,z,z,z
time = 0

[Command]
name = "AI14"
command = a,a,a,a
time = 0

[Command]
name = "AI15"
command = b,b,b,b
time = 0

[Command]
name = "AI16"
command = c,c,c,c
time = 0

[Command]
name = "AI17"
command = U,x,U,x
time = 0

[Command]
name = "AI18"
command = D,x,D,x
time = 0

[Command]
name = "AI19"
command = B,x,B,x
time = 0

[Command]
name = "AI20"
command = F,x,F,x
time = 0

[Command]
name = "KonamiCode"
command = U,U,D,D,B,F,B,F,b,a,s
time = 0

[Command]
name = "aXOR"
command = a
time = 1

[Command]
name = "bXOR"
command = b
time = 1

[Command]
name = "cXOR"
command = c
time = 1

[Command]
name = "xXOR"
command = x
time = 1

[Command]
name = "yXOR"
command = y
time = 1

[Command]
name = "zXOR"
command = z
time = 1

[Command]
name = "startXOR"
command = s
time = 1

[Command]
name = "holdfwdXOR"
command = /$F
time = 1

[Command]
name = "holdbackXOR"
command = /$B
time = 1

[Command]
name = "holdupXOR"
command = /$U
time = 1

[Command]
name = "holddownXOR"
command = /$D
time = 1

[Command]
name = "holdxXOR"
command = /x
time = 1

[Command]
name = "holdyXOR"
command = /y
time = 1

[Command]
name = "holdzXOR"
command = /z
time = 1

[Command]
name = "holdaXOR"
command = /a
time = 1

[Command]
name = "holdbXOR"
command = /b
time = 1

[Command]
name = "holdcXOR"
command = /c
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
; AI
;===========================================================================
;---------------------------------------------------------------------------
;Activate AI
[State -1, Activate AI]
type = VarSet
triggerall = var(59) = 0
triggerall = var(57) != 1 ; Difficulty level not set to No AI
triggerall = !isHelper
trigger1 = IsHomeTeam
trigger1 = TeamSide = 2
trigger2 = command = "KonamiCode"
trigger3 = command = "AI1"
trigger4 = command = "AI2"
trigger5 = command = "AI3"
trigger6 = command = "AI4"
trigger7 = command = "AI5"
trigger8 = command = "AI6"
trigger9 = command = "AI7"
trigger10 = command = "AI8"
trigger11 = command = "AI9"
trigger12 = command = "AI10"
trigger13 = command = "AI11"
trigger14 = command = "AI12"
trigger15 = command = "AI13"
trigger16 = command = "AI14"
trigger17 = command = "AI15"
trigger18 = command = "AI16"
trigger19 = command = "AI17"
trigger20 = command = "AI18"
trigger21 = command = "AI19"
trigger22 = command = "AI20"
trigger23 = command = "a" ^^ command = "aXOR"
trigger24 = command = "b" ^^ command = "bXOR"
trigger25 = command = "c" ^^ command = "cXOR"
trigger26 = command = "x" ^^ command = "xXOR"
trigger27 = command = "y" ^^ command = "yXOR"
trigger28 = command = "z" ^^ command = "zXOR"
trigger29 = command = "start" ^^ command = "startXOR"
trigger30 = command = "holdfwd" ^^ command = "holdfwdXOR"
trigger31 = command = "holdback" ^^ command = "holdbackXOR"
trigger32 = command = "holdup" ^^ command = "holdupXOR"
trigger33 = command = "holddown" ^^ command = "holddownXOR"
trigger34 = command = "holda" ^^ command = "holdaXOR"
trigger35 = command = "holdb" ^^ command = "holdbXOR"
trigger36 = command = "holdc" ^^ command = "holdcXOR"
trigger37 = command = "holdx" ^^ command = "holdxXOR"
trigger38 = command = "holdy" ^^ command = "holdyXOR"
trigger39 = command = "holdz" ^^ command = "holdzXOR"
v = 59
value = 1

;---------------------------------------------------------------------------
;Activate AI
[State -1, Activate AI]
type = VarSet
triggerall = var(59) = 2
trigger1 = RoundState < 3
v = 59
value = 1

;---------------------------------------------------------------------------
;Deactivate AI
[State -1, Deactivate AI]
type = VarSet
triggerall = var(59) != 0
trigger1 = RoundState >= 3
v = 59
value = 2

;---------------------------------------------------------------------------
;Liedown AI
[State -1, Liedown AI]
type = VarSet
triggerall = var(59) = 1
trigger1 = p2statetype = L
trigger2 = p2stateno = [5050,5079]
v = 59
value = 4

;---------------------------------------------------------------------------
;Liedown AI Off
[State -1, Liedown AI Off]
type = VarSet
triggerall = var(59) = 4
trigger1 = p2statetype != L
trigger1 = p2stateno != [5050,5079]
v = 59
value = 1

;---------------------------------------------------------------------------
;Check Miss AI Begin Attack
[State -1, Check Miss AI Begin Attack]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) <= 0
trigger1 = movetype = A
v = 58
value = stateno

;---------------------------------------------------------------------------
;Check Miss AI Hit
[State -1, Check Miss AI Hit]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) != 0
trigger1 = movecontact
trigger2 = movetype = I
trigger2 = random < 10
trigger3 = stateno = [150,159]
v = 58
value = 0

;---------------------------------------------------------------------------
;Check Miss AI End Attack
[State -1, Check Miss AI End Attack]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) > 0
trigger1 = ctrl = 1
v = 58
value = var(58)*(-1)

;===========================================================================
; AI Defense
;===========================================================================
;---------------------------------------------------------------------------
;Rebuttal
[State -1, Rebuttal]
type = ChangeState
value = 1020
triggerall = var(59) = 1
trigger1 = inguarddist
trigger1 = enemy, numproj > 0
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Out of Office
[State -1, Out of Office]
type = ChangeState
value = 1010
triggerall = var(59) = 1
trigger1 = P2BodyDist X < 60
trigger1 = inguarddist
trigger1 = Random < 100
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Diplomatic Immunity
[State -1, Diplomatic Immunity]
type = ChangeState
value = 1000
triggerall = var(59) = 1
trigger1 = P2BodyDist X < 60
trigger1 = inguarddist
trigger1 = Random < 100
trigger1 = statetype != A
trigger1 = ctrl

;===========================================================================
; AI Guard
;===========================================================================
;---------------------------------------------------------------------------
;AI Guard (Standing)
[State -1, AI Guard (Standing)]
type = ChangeState
value = 130
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype != C
trigger1 = inguarddist

;---------------------------------------------------------------------------
;AI Guard (Crouching)
[State -1, AI Guard (Crouching)]
type = ChangeState
value = 131
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype = C
trigger1 = inguarddist

;---------------------------------------------------------------------------
;AI Guard (Air)
[State -1, AI Guard (Air)]
type = ChangeState
value = 132
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = statetype = A
triggerall = ctrl
trigger1 = inguarddist

;===========================================================================
; AI Throws
;===========================================================================
;---------------------------------------------------------------------------
;AI Kung Fu Throw
;
[State -1, AI Kung Fu Throw]
type = ChangeState
value = 800
triggerall = var(59) = 1
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = P2BodyDist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = P2BodyDist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
; AI Special Attacks
;===========================================================================
;---------------------------------------------------------------------------
;AI Impeach
[State -1, AI Impeach]
type = ChangeState
value = 1070
triggerall = var(59) = 1
triggerall = var(0) = 0  ;Impeach Time Left
trigger1 = Random < 5
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Veto
[State -1, AI Veto]
type = ChangeState
value = 1050
triggerall = var(59) = 1
triggerall = numproj = 0
triggerall = NumExplod(1041) = 0
triggerall = NumExplod(1051) = 0
triggerall = NumExplod(1061) = 0
triggerall = Random < 15
triggerall = -var(58) != 1050
triggerall = P2BodyDist X > 100
triggerall = P2BodyDist Y = [-20,10]
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Campaign Donation
[State -1, AI Campaign Donation]
type = ChangeState
value = 1100
triggerall = var(59) = 1
triggerall = numproj = 0
triggerall = Random < 75
triggerall = -var(58) != 1100
triggerall = P2BodyDist X > 100
triggerall = P2BodyDist Y = [-20,10]
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Kickback
[State -1, AI Kickback]
type = ChangeState
value = 1080
triggerall = var(59) = 1
trigger1 = P2BodyDist X < 50
trigger1 = Random < 200
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Taunt - Mud Slinger
[State -1, AI Taunt - Mud Slinger]
type = ChangeState
value = 195
triggerall = var(59) = 1
triggerall = command = "start" || command = "BF_xz"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Voter Pin Stab
[State -1, AI Voter Pin Stab]
type = ChangeState
value = 1030
triggerall = var(59) = 1
triggerall = command = "QCF_z"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Ban Violence
[State -1, AI Ban Violence]
type = ChangeState
value = 1040
triggerall = var(59) = 1
triggerall = numproj = 0
triggerall = NumExplod(1041) = 0
triggerall = NumExplod(1051) = 0
triggerall = NumExplod(1061) = 0
triggerall = Random < 15
triggerall = -var(58) != 1040
triggerall = P2BodyDist X > 100
triggerall = P2BodyDist Y = [-20,10]
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Red Tape
[State -1, AI Red Tape]
type = ChangeState
value = 1060
triggerall = var(59) = 1
triggerall = numproj = 0
triggerall = NumExplod(1061) = 0
triggerall = Random < 15
triggerall = -var(58) != 1060
triggerall = P2BodyDist X > 100
triggerall = P2BodyDist Y = [-20,10]
trigger1 = statetype != A
trigger1 = ctrl

;===========================================================================
; AI Normal Attacks
;===========================================================================
;===========================================================================
;---------------------------------------------------------------------------
;AI Stand Close Light Punch
[State -1, AI Stand Close Light Punch]
type = ChangeState
value = 205
triggerall = var(59) = 1
triggerall = P2BodyDist X < 15
triggerall = -var(58) != [200,205]
triggerall = -var(58) != [230,235]
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Stand Close Medium Punch
[State -1, AI Stand Close Medium Punch]
type = ChangeState
value = 215
triggerall = var(59) = 1
triggerall = P2BodyDist X < 15
triggerall = -var(58) != [210,215]
triggerall = -var(58) != [240,245]
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Stand Close Strong Punch
[State -1, AI Stand Close Strong Punch]
type = ChangeState
value = 225
triggerall = var(59) = 1
triggerall = P2BodyDist X < 15
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Stand Close Light Kick
[State -1, AI Stand Close Light Kick]
type = ChangeState
value = 235
triggerall = var(59) = 1
triggerall = P2BodyDist X < 15
triggerall = -var(58) != [200,205]
triggerall = -var(58) != [230,235]
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Standing Close Medium Kick
[State -1, AI Standing Close Medium Kick]
type = ChangeState
value = 245
triggerall = var(59) = 1
triggerall = P2BodyDist X < 15
triggerall = -var(58) != [210,215]
triggerall = -var(58) != [240,245]
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Standing Close Strong Kick
[State -1, AI Standing Close Strong Kick]
type = ChangeState
value = 255
triggerall = var(59) = 1
triggerall = P2BodyDist X < 15
triggerall = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Stand Light Punch
[State -1, AI Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(59) = 1
triggerall = P2BodyDist X < 30
triggerall = -var(58) != [200,205]
triggerall = -var(58) != [230,235]
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Stand Medium Punch
[State -1, AI Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(59) = 1
triggerall = P2BodyDist X < 35
triggerall = -var(58) != [210,215]
triggerall = -var(58) != [240,245]
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Stand Strong Punch
[State -1, AI Stand Strong Punch]
type = ChangeState
value = 220
triggerall = var(59) = 1
triggerall = P2BodyDist X < 40
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Stand Light Kick
[State -1, AI Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(59) = 1
triggerall = P2BodyDist X < 70
triggerall = -var(58) != [200,205]
triggerall = -var(58) != [230,235]
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 200

;---------------------------------------------------------------------------
;AI Standing Medium Kick
[State -1, AI Standing Medium Kick]
type = ChangeState
value = 240
triggerall = var(59) = 1
triggerall = P2BodyDist X < 45
triggerall = -var(58) != [210,215]
triggerall = -var(58) != [240,245]
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Standing Strong Kick
[State -1, AI Standing Strong Kick]
type = ChangeState
value = 250
triggerall = var(59) = 1
triggerall = P2BodyDist X < 35
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Crouching Light Punch
[State -1, AI Crouching Light Punch]
type = ChangeState
value = 400
triggerall = var(59) = 1
triggerall = P2BodyDist X < 20
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Crouching Medium Punch
[State -1, AI Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = var(59) = 1
triggerall = P2BodyDist X < 30
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Crouching Strong Punch
[State -1, AI Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = var(59) = 1
triggerall = P2BodyDist X < 35
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Crouching Light Kick
[State -1, AI Crouching Light Kick]
type = ChangeState
value = 430
triggerall = var(59) = 1
triggerall = P2BodyDist X < 25
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Crouching Medium Kick
[State -1, AI Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = var(59) = 1
triggerall = P2BodyDist X < 40
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Crouching Strong Kick
[State -1, AI Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = var(59) = 1
triggerall = P2BodyDist X < 65
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Forwards Medium Punch
[State -1, AI Jump Forwards Medium Punch]
type = ChangeState
value = 615
triggerall = var(59) = 1
triggerall = p2bodydist X = [0,20] 
triggerall = p2dist Y - (vel Y)*4 = [-20,20]
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Forwards Medium Kick
[State -1, AI Jump Forwards Medium Kick]
type = ChangeState
value = 645
triggerall = var(59) = 1
triggerall = p2bodydist X = [0,20] 
triggerall = p2dist Y - (vel Y)*4 = [-20,20]
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Forwards Strong Kick
[State -1, AI Jump Forwards Strong Kick]
type = ChangeState
value = 655
triggerall = var(59) = 1
triggerall = p2bodydist X = [0,20] 
triggerall = p2dist Y - (vel Y)*6 = [-20,20]
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Light Punch
[State -1, AI Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) = 1
triggerall = p2bodydist X + (vel X)*2 = [0,20] 
triggerall = p2dist Y - (vel Y)*2 = [-20,20]
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Medium Punch
[State -1, AI Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(59) = 1
triggerall = p2bodydist X + (vel X)*4 = [0,20] 
triggerall = p2dist Y - (vel Y)*4 = [-20,20]
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Strong Punch
[State -1, AI Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(59) = 1
triggerall = p2bodydist X + (vel X)*6 = [0,20] 
triggerall = p2dist Y - (vel Y)*6 = [-20,20]
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Light Kick
[State -1, AI Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) = 1
triggerall = p2bodydist X + (vel X)*2 = [0,20] 
triggerall = p2dist Y - (vel Y)*2 = [-20,20]
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Medium Kick
[State -1, AI Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(59) = 1
triggerall = p2bodydist X + (vel X)*4 = [0,20] 
triggerall = p2dist Y - (vel Y)*4 = [-20,20]
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;---------------------------------------------------------------------------
;AI Jump Strong Kick
[State -1, AI Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(59) = 1
triggerall = p2bodydist X + (vel X)*6 = [0,20] 
triggerall = p2dist Y - (vel Y)*6 = [-20,20]
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Random < 300

;===========================================================================
; End of AI Section
;===========================================================================

;===========================================================================
;;---------------------------------------------------------------------------
;;Triple Kung Fu Palm (uses one super bar)
;;OJt[˂iQ[WxPj
;[State -1, Triple Kung Fu Palm]
;type = ChangeState
;value = 3000
;triggerall = command = "TripleKFPalm"
;triggerall = power >= 1000
;trigger1 = statetype = S
;trigger1 = ctrl
;trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA, HA
;trigger2 = stateno != [3000,3050)
;trigger2 = movecontact

;===========================================================================
;---------------------------------------------------------------------------
;Diplomatic Immunity
[State -1, Diplomatic Immunity]
type = ChangeState
value = 1000
triggerall = var(59) = 0
triggerall = command = "xyz"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Impeach
[State -1, Impeach]
type = ChangeState
value = 1070
triggerall = var(59) = 0
triggerall = command = "abc"
triggerall = var(0) = 0  ;Impeach Time Left
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Out of Office
[State -1, Out of Office]
type = ChangeState
value = 1010
triggerall = var(59) = 0
triggerall = command = "QCB_c"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Veto
[State -1, Veto]
type = ChangeState
value = 1050
triggerall = var(59) = 0
triggerall = command = "BF_xy"
triggerall = numproj = 0
triggerall = NumExplod(1041) = 0
triggerall = NumExplod(1051) = 0
triggerall = NumExplod(1061) = 0
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Campaign Donation
[State -1, Campaign Donation]
type = ChangeState
value = 1100
triggerall = var(59) = 0
triggerall = command = "QCF_bc"
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Kickback
[State -1, Kickback]
type = ChangeState
value = 1080
triggerall = var(59) = 0
triggerall = command = "BF_bc"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Taunt - Mud Slinger
[State -1, Taunt - Mud Slinger]
type = ChangeState
value = 195
triggerall = var(59) = 0
triggerall = command = "start" || command = "BF_xz"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Rebuttal
[State -1, Rebuttal]
type = ChangeState
value = 1020
triggerall = var(59) = 0
triggerall = command = "BF_x"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Voter Pin Stab
[State -1, Voter Pin Stab]
type = ChangeState
value = 1030
triggerall = var(59) = 0
triggerall = command = "QCF_z"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Ban Violence
[State -1, Ban Violence]
type = ChangeState
value = 1040
triggerall = var(59) = 0
triggerall = command = "BF_c"
triggerall = numproj = 0
triggerall = NumExplod(1041) = 0
triggerall = NumExplod(1051) = 0
triggerall = NumExplod(1061) = 0
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Red Tape
[State -1, Red Tape]
type = ChangeState
value = 1060
triggerall = var(59) = 0
triggerall = command = "BF_y"
triggerall = numproj = 0
triggerall = NumExplod(1061) = 0
trigger1 = statetype != A
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = var(59) = 0
triggerall = command = "y" || command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = P2BodyDist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = P2BodyDist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;===========================================================================
;---------------------------------------------------------------------------
;Stand Close Light Punch
[State -1, Stand Close Light Punch]
type = ChangeState
value = 205
triggerall = var(59) = 0
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 15
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Close Medium Punch
[State -1, Stand Close Medium Punch]
type = ChangeState
value = 215
triggerall = var(59) = 0
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 15
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Close Strong Punch
[State -1, Stand Close Strong Punch]
type = ChangeState
value = 225
triggerall = var(59) = 0
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 15
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Close Light Kick
[State -1, Stand Close Light Kick]
type = ChangeState
value = 235
triggerall = var(59) = 0
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 15
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Close Medium Kick
[State -1, Standing Close Medium Kick]
type = ChangeState
value = 245
triggerall = var(59) = 0
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 15
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Close Strong Kick
[State -1, Standing Close Strong Kick]
type = ChangeState
value = 255
triggerall = var(59) = 0
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 15
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(59) = 0
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(59) = 0
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = var(59) = 0
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(59) = 0
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = var(59) = 0
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = var(59) = 0
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = var(59) = 0
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = var(59) = 0
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = var(59) = 0
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = var(59) = 0
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = var(59) = 0
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = var(59) = 0
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Forwards Medium Punch
[State -1, Jump Forwards Medium Punch]
type = ChangeState
value = 615
triggerall = var(59) = 0
triggerall = command = "y"
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Forwards Medium Kick
[State -1, Jump Forwards Medium Kick]
type = ChangeState
value = 645
triggerall = var(59) = 0
triggerall = command = "b"
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Forwards Strong Kick
[State -1, Jump Forwards Strong Kick]
type = ChangeState
value = 655
triggerall = var(59) = 0
triggerall = command = "c"
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) = 0
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(59) = 0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(59) = 0
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) = 0
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(59) = 0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(59) = 0
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
